==> alloyeditor-0.6.0.jar: META-INF/resources/webjars/alloyeditor/0.6.0/src/ui/react/_processed_lang_keys.js <==
AlloyEditor.Strings = {
	alignCenter: CKEDITOR.lang['{lang}'].common.alignCenter,
	alignJustify: CKEDITOR.lang['{lang}'].common.alignJustify,
	alignLeft: CKEDITOR.lang['{lang}'].common.alignLeft,
	alignRight: CKEDITOR.lang['{lang}'].common.alignRight,
	bold: CKEDITOR.lang['{lang}'].basicstyles.bold,
	bulletedlist: CKEDITOR.lang['{lang}'].list.bulletedlist,
	cancel: CKEDITOR.lang['{lang}'].common.cancel,
	horizontalrule: CKEDITOR.lang['{lang}'].horizontalrule.toolbar,
	italic: CKEDITOR.lang['{lang}'].basicstyles.italic,
	numberedlist: CKEDITOR.lang['{lang}'].list.numberedlist,
	quote: CKEDITOR.lang['{lang}'].blockquote.toolbar,
	removeformat: CKEDITOR.lang['{lang}'].removeformat.toolbar,
	strike: CKEDITOR.lang['{lang}'].basicstyles.strike,
	subscript: CKEDITOR.lang['{lang}'].basicstyles.subscript,
	superscript: CKEDITOR.lang['{lang}'].basicstyles.superscript,
	underline: CKEDITOR.lang['{lang}'].basicstyles.underline,

	formatted: CKEDITOR.lang['{lang}'].format.tag_pre,
	h1: CKEDITOR.lang['{lang}'].format.tag_h1,
	h2: CKEDITOR.lang['{lang}'].format.tag_h2,
	normal: CKEDITOR.lang['{lang}'].format.tag_p,

	blockStyles: CKEDITOR.lang['{lang}'].stylescombo.panelTitle1,
	inlineStyles: CKEDITOR.lang['{lang}'].stylescombo.panelTitle2,
	objectStyles: CKEDITOR.lang['{lang}'].stylescombo.panelTitle3,
	styles: CKEDITOR.lang['{lang}'].stylescombo.label,

	cell: CKEDITOR.lang['{lang}'].table.cell.menu,
	cellDelete: CKEDITOR.lang['{lang}'].table.cell.deleteCell,
	cellInsertAfter: CKEDITOR.lang['{lang}'].table.cell.insertAfter,
	cellInsertBefore: CKEDITOR.lang['{lang}'].table.cell.insertBefore,
	cellMerge: CKEDITOR.lang['{lang}'].table.cell.merge,
	cellMergeDown: CKEDITOR.lang['{lang}'].table.cell.mergeDown,
	cellMergeRight: CKEDITOR.lang['{lang}'].table.cell.mergeRight,
	cellSplitHorizontal: CKEDITOR.lang['{lang}'].table.cell.splitHorizontal,
	cellSplitVertical: CKEDITOR.lang['{lang}'].table.cell.splitVertical,
	column: CKEDITOR.lang['{lang}'].table.column.menu,
	columnDelete: CKEDITOR.lang['{lang}'].table.column.deleteColumn,
	columnInsertAfter: CKEDITOR.lang['{lang}'].table.column.insertAfter,
	columnInsertBefore: CKEDITOR.lang['{lang}'].table.column.insertBefore,
	deleteTable: CKEDITOR.lang['{lang}'].table.deleteTable,
	headers: CKEDITOR.lang['{lang}'].table.headers,
	headersBoth: CKEDITOR.lang['{lang}'].table.headersBoth,
	headersColumn: CKEDITOR.lang['{lang}'].table.headersColumn,
	headersNone: CKEDITOR.lang['{lang}'].table.headersNone,
	headersRow: CKEDITOR.lang['{lang}'].table.headersRow,
	row: CKEDITOR.lang['{lang}'].table.row.menu,
	rowDelete: CKEDITOR.lang['{lang}'].table.row.deleteRow,
	rowInsertAfter: CKEDITOR.lang['{lang}'].table.row.insertAfter,
	rowInsertBefore: CKEDITOR.lang['{lang}'].table.row.insertBefore,

	/* Custom strings not available in CKEditor */
	add: 'Add',
	ariaUpdateNoToolbar: 'No toolbars are available',
	ariaUpdateOneToolbar: '{toolbars} toolbar is available. Press ALT+F10 to focus.',
	ariaUpdateManyToolbars: '{toolbars} toolbars are available. Press ALT+F10 to focus.',
	camera: 'Insert Image from Camera',
	cite: 'Cite',
	code: 'Code',
	clearInput: 'Clear Input Field',
	confirm: 'Confirm',
	editLink: 'Type or paste link here',
	image: 'Insert Image',
	link: 'Link',
	removeLink: 'Remove link',
	table: 'Insert Table',
	twitter: 'Twitter'
};

==> alloyeditor-0.7.2.jar: META-INF/resources/webjars/alloyeditor/0.7.2/src/ui/react/_processed_lang_keys.js <==
AlloyEditor.Strings = {
	alignCenter: CKEDITOR.lang['{lang}'].common.alignCenter,
	alignJustify: CKEDITOR.lang['{lang}'].common.alignJustify,
	alignLeft: CKEDITOR.lang['{lang}'].common.alignLeft,
	alignRight: CKEDITOR.lang['{lang}'].common.alignRight,
	bold: CKEDITOR.lang['{lang}'].basicstyles.bold,
	bulletedlist: CKEDITOR.lang['{lang}'].list.bulletedlist,
	cancel: CKEDITOR.lang['{lang}'].common.cancel,
	horizontalrule: CKEDITOR.lang['{lang}'].horizontalrule.toolbar,
	italic: CKEDITOR.lang['{lang}'].basicstyles.italic,
	numberedlist: CKEDITOR.lang['{lang}'].list.numberedlist,
	quote: CKEDITOR.lang['{lang}'].blockquote.toolbar,
	removeformat: CKEDITOR.lang['{lang}'].removeformat.toolbar,
	strike: CKEDITOR.lang['{lang}'].basicstyles.strike,
	subscript: CKEDITOR.lang['{lang}'].basicstyles.subscript,
	superscript: CKEDITOR.lang['{lang}'].basicstyles.superscript,
	underline: CKEDITOR.lang['{lang}'].basicstyles.underline,

	formatted: CKEDITOR.lang['{lang}'].format.tag_pre,
	h1: CKEDITOR.lang['{lang}'].format.tag_h1,
	h2: CKEDITOR.lang['{lang}'].format.tag_h2,
	normal: CKEDITOR.lang['{lang}'].format.tag_p,

	blockStyles: CKEDITOR.lang['{lang}'].stylescombo.panelTitle1,
	inlineStyles: CKEDITOR.lang['{lang}'].stylescombo.panelTitle2,
	objectStyles: CKEDITOR.lang['{lang}'].stylescombo.panelTitle3,
	styles: CKEDITOR.lang['{lang}'].stylescombo.label,

	cell: CKEDITOR.lang['{lang}'].table.cell.menu,
	cellDelete: CKEDITOR.lang['{lang}'].table.cell.deleteCell,
	cellInsertAfter: CKEDITOR.lang['{lang}'].table.cell.insertAfter,
	cellInsertBefore: CKEDITOR.lang['{lang}'].table.cell.insertBefore,
	cellMerge: CKEDITOR.lang['{lang}'].table.cell.merge,
	cellMergeDown: CKEDITOR.lang['{lang}'].table.cell.mergeDown,
	cellMergeRight: CKEDITOR.lang['{lang}'].table.cell.mergeRight,
	cellSplitHorizontal: CKEDITOR.lang['{lang}'].table.cell.splitHorizontal,
	cellSplitVertical: CKEDITOR.lang['{lang}'].table.cell.splitVertical,
	column: CKEDITOR.lang['{lang}'].table.column.menu,
	columnDelete: CKEDITOR.lang['{lang}'].table.column.deleteColumn,
	columnInsertAfter: CKEDITOR.lang['{lang}'].table.column.insertAfter,
	columnInsertBefore: CKEDITOR.lang['{lang}'].table.column.insertBefore,
	deleteTable: CKEDITOR.lang['{lang}'].table.deleteTable,
	headers: CKEDITOR.lang['{lang}'].table.headers,
	headersBoth: CKEDITOR.lang['{lang}'].table.headersBoth,
	headersColumn: CKEDITOR.lang['{lang}'].table.headersColumn,
	headersNone: CKEDITOR.lang['{lang}'].table.headersNone,
	headersRow: CKEDITOR.lang['{lang}'].table.headersRow,
	row: CKEDITOR.lang['{lang}'].table.row.menu,
	rowDelete: CKEDITOR.lang['{lang}'].table.row.deleteRow,
	rowInsertAfter: CKEDITOR.lang['{lang}'].table.row.insertAfter,
	rowInsertBefore: CKEDITOR.lang['{lang}'].table.row.insertBefore,

	/* Custom strings not available in CKEditor */
	add: 'Add',
	ariaUpdateNoToolbar: 'No toolbars are available',
	ariaUpdateOneToolbar: '{toolbars} toolbar is available. Press ALT+F10 to focus.',
	ariaUpdateManyToolbars: '{toolbars} toolbars are available. Press ALT+F10 to focus.',
	camera: 'Insert Image from Camera',
	cite: 'Cite',
	code: 'Code',
	clearInput: 'Clear Input Field',
	confirm: 'Confirm',
	editLink: 'Type or paste link here',
	image: 'Insert Image',
	link: 'Link',
	linkTargetBlank: '_blank (new tab)',
	linkTargetDefault: 'default',
	linkTargetParent: '_parent',
	linkTargetSelf: '_self (same tab)',
	linkTargetTop: '_top',
	removeLink: 'Remove link',
	table: 'Insert Table',
	twitter: 'Twitter'
};
